#include <stdio.h>
#include "dukterm.h"

bool dukterm_read_file(duk_context *ctx, const char *filename) {
	char buffer[256];
	FILE *fp = fopen(filename, "r");
	if (!fp) {
		fprintf(stderr, "Can't open file %s\n", filename);
		return FALSE;
	}
	duk_push_string(ctx, "");
	while (fgets(buffer, sizeof(buffer), fp) != NULL) {
		duk_push_string(ctx, buffer);
		duk_concat(ctx, 2);
	}
	return TRUE;
}

void dukterm_fatal(void *user_data, const char *msg) {
	if (!isendwin())
		endwin();
	if (msg)
		fprintf(stderr, "Fatal error; %s\n", msg);
	else
		fprintf(stderr, "Fatal error in Duktape\n");
	fflush(stderr);
	abort();
}

int main(int argc, char **argv) {
	duk_context *ctx =
		duk_create_heap(NULL, NULL, NULL, NULL, dukterm_fatal);
	dukterm_bind_to(ctx);
	
	if (argc < 2) {
		puts("Usage: dukterm <file>...");
	} else {
		for (int i = 1; i < argc; i++) {
			if (dukterm_read_file(ctx, argv[i])) {
				duk_push_string(ctx, argv[i]);
				duk_compile(ctx, 0);
				duk_call(ctx, 0);
				duk_pop(ctx);
			}
		}
	}
	
	duk_destroy_heap(ctx);
	return 0;
}
